.. default-domain:: py
.. currentmodule:: fastnumbers

The "Checking" Functions
========================

These functions return a Boolean value that indicates if the input
is a certain number type or not.

:func:`~fastnumbers.isreal`
---------------------------

.. autofunction:: isreal

:func:`~fastnumbers.isfloat`
----------------------------

.. autofunction:: isfloat

:func:`~fastnumbers.isint`
--------------------------

.. autofunction:: isint

:func:`~fastnumbers.isintlike`
------------------------------

.. autofunction:: isintlike
